[![Python Linting](https://github.com/tarekmulla/hax-core/actions/workflows/linting.yml/badge.svg)](https://github.com/tarekmulla/hax-core/actions/workflows/linting.yml) [![PyTest](https://github.com/tarekmulla/hax-core/actions/workflows/test.yml/badge.svg)](https://github.com/tarekmulla/hax-core/actions/workflows/test.yml) [![Release](https://github.com/tarekmulla/hax-core/actions/workflows/release.yml/badge.svg)](https://github.com/tarekmulla/hax-core/actions/workflows/release.yml)

# HaX Core package

This repository contains the PyPi package for the core code of the [HaX Cybersecurity tool](https://www.haxsec.com/).

## About the project

[HaX](https://www.haxsec.com/) is an AI-powered Cybersecurity tool designed to detect website vulnerabilities. Its cloud connection enhances capabilities for advanced analytics and modeling.
This tool is expertly designed for ethical hacking, using intelligent cyber attack simulations to identify successful outcomes. It uploads results to the cloud for advanced data analytics, refining models for future attacks.

<p align="center">
  <img src="https://haxsec.com/images/logo.png" alt="design" width="40%"/>
</p>

## Deployment prerequisites

Before running the application, make sure to meet the following requirements

- Download and install python latest version, [check here](https://www.python.org/downloads/).
- Install pip, [check here](https://pip.pypa.io/en/stable/installation/).
- Install poetry, [check here](https://python-poetry.org/docs/).
- Install all dependencies by running  `poetry install`, the command will create a virtual environment, to understand how poetry works please refer to this [documentation](https://python-poetry.org/docs/configuration).
- You can run pytest using command `poetry run pytest`

## Who do I talk to?

You can contact us directly using one of the following:
* 🖥️ Website: [haxsec.com](https://www.haxsec.com/)
* ✉️ Support Email [support@haxsec.com](mailto:support@haxsec.com)
